@@ -24,7 +24,7 @@ use Dist::Zilla::Role::PluginBundle                   ();
 use Dist::Zilla::Role::PluginBundle::Easy             ();
 use Dist::Zilla::Util                                 ();
 
-our $VERSION = '1.6';
+our $VERSION = '1.7';
 
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -56,6 +56,24 @@ has license => (
     default  => sub { $_[0]->payload->{license} // 'LICENSE' },
 );
 
+has exclude_files => (
+    isa      => 'ArrayRef[Str]',
+    init_arg => undef,
+    lazy     => 1,
+    default  => sub { $_[0]->payload->{exclude_files} // [] },
+    traits   => ['Array'],
+    handles => { exclude_files => 'elements' },
+);
+
+around exclude_files => sub {
+    my $orig = shift;
+    my $self = shift;
+    sort(uniq(
+            $self->$orig(@_),
+            qw(Dockerfile .gitlab-ci.yml docker-compose.yml docker-compose.override.yml)
+    ));
+};
+
 has copy_file_from_build => (
     isa      => 'ArrayRef[Str]',
     init_arg => undef,
@@ -70,7 +88,7 @@ around copy_files_from_build => sub {
     my $self = shift;
     sort(uniq(
             $self->$orig(@_),
-            qw(Makefile.PL cpanfile Build.PL)
+            qw(Makefile.PL cpanfile Build.PL README)
     ));
 };
 
@@ -88,7 +106,7 @@ around copy_files_from_release => sub {
     my $self = shift;
     sort(uniq(
             $self->$orig(@_),
-            qw(LICENCE LICENSE CONTRIBUTING ppport.h INSTALL README)
+            qw(LICENCE LICENSE CONTRIBUTING ppport.h INSTALL)
     ));
 };
 
@@ -213,8 +231,11 @@ sub configure {
         [
             'Git::GatherDir' => {
                 do {
-                    my @filenames
-                        = uniq(grep { -e } $self->copy_files_from_release, $self->copy_files_from_build);
+                    my @filenames = uniq(
+                        grep { -e } $self->copy_files_from_release,
+                        $self->copy_files_from_build,
+                        $self->exclude_files,
+                    );
                     @filenames ? (exclude_filename => \@filenames) : ();
                 },
             },
@@ -276,6 +297,20 @@ sub configure {
         push @plugins, 'BlockRelease';
     }
 
+    # Disable test::perl::critic as it messes with the version rewrite
+    # that happens during a build
+    # Also disable portability files as foo.conf.dist is not allowed :(
+    $self->add_bundle(
+        '@TestingMania' => {
+            disable => [
+                qw(
+                    Test::Perl::Critic
+                    Test::Portability::Files
+                )
+            ]
+        }
+    );
+
     # plugins to do with calculating, munging, incrementing versions
     $self->add_bundle(
         '@Git::VersionManager' => {
@@ -304,7 +339,6 @@ sub configure {
                 . 'v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T',
         }
     );
-    $self->add_bundle('@TestingMania');
     $self->add_plugins(@plugins);
 
 }
@@ -323,7 +357,7 @@ Dist::Zilla::PluginBundle::Author::WATERKIP - An plugin bundle for all distribut
 
 =head1 VERSION
 
-version 1.6
+version 1.7
 
 =head1 SYNOPSIS
 
